@@ -413,7 +413,7 @@ if(flags&TR_ASCII)
 	if(GLOBALS->show_base) { *(pnt++)='"'; }
 
 	parse=(flags&TR_RJUSTIFY)?(newbuff+((nbits+7)&7)):(newbuff+7);
-	cvt_gray(flags,parse,nbits);
+	cvt_gray(flags,parse,(flags&TR_RJUSTIFY)?((nbits+7)&~7):nbits);
 
 	for(i=0;i<nbits;i+=8)
 		{
@@ -453,7 +453,7 @@ else if((flags&TR_HEX)||((flags&(TR_DEC|TR_SIGNED))&&(nbits>64)&&(!(flags&TR_POP
 	if(GLOBALS->show_base) { *(pnt++)='$'; }
 
 	parse=(flags&TR_RJUSTIFY)?(newbuff+((nbits+3)&3)):(newbuff+3);
-	cvt_gray(flags,parse,nbits);
+	cvt_gray(flags,parse,(flags&TR_RJUSTIFY)?((nbits+3)&~3):nbits);
 
 	for(i=0;i<nbits;i+=4)
 		{
@@ -614,7 +614,7 @@ else if(flags&TR_OCT)
 	parse=(flags&TR_RJUSTIFY)
 		?(newbuff+((nbits%3)?(nbits%3):3))
 		:(newbuff+3);
-	cvt_gray(flags,parse,nbits);
+	cvt_gray(flags,parse,(flags&TR_RJUSTIFY)?(((nbits+2)/3)*3):nbits);
 
 	for(i=0;i<nbits;i+=3)
 		{
@@ -708,10 +708,12 @@ else if(flags&TR_REAL)
 	{
 	char *parse;
 
-	if(nbits==64)
+	if((nbits==64) || (nbits==32))
 		{
 		UTimeType utt = LLDescriptor(0);
 		double d;
+		float f;
+		uint32_t utt_32;
 
 		parse=newbuff+3;
 		cvt_gray(flags,parse,nbits);
@@ -733,9 +735,18 @@ else if(flags&TR_REAL)
 				}
 			}
 
-		memcpy(&d, &utt, sizeof(double));
-		os=/*pnt=*/(char *)calloc_2(1,32); /* scan-build */
-		sprintf(os, "%.16g", d);
+		os=/*pnt=*/(char *)calloc_2(1,64); /* scan-build */
+		if(nbits==64)
+			{
+			memcpy(&d, &utt, sizeof(double));
+			sprintf(os, "%.16g", d);
+			}
+			else
+			{
+			utt_32 = utt;
+			memcpy(&f, &utt_32, sizeof(float));
+			sprintf(os, "%f", f);
+			}
 		}
 		else
 		{
@@ -1117,7 +1128,7 @@ if(flags&TR_ASCII)
 	if(GLOBALS->show_base) { *(pnt++)='"'; }
 
 	parse=(flags&TR_RJUSTIFY)?(newbuff+((nbits+7)&7)):(newbuff+7);
-	cvt_gray(flags,parse,nbits);
+	cvt_gray(flags,parse,(flags&TR_RJUSTIFY)?((nbits+7)&~7):nbits);
 
 	for(i=0;i<nbits;i+=8)
 		{
@@ -1156,7 +1167,7 @@ else if((flags&TR_HEX)||((flags&(TR_DEC|TR_SIGNED))&&(nbits>64)&&(!(flags&TR_POP
 	if(GLOBALS->show_base) { *(pnt++)='$'; }
 
 	parse=(flags&TR_RJUSTIFY)?(newbuff+((nbits+3)&3)):(newbuff+3);
-	cvt_gray(flags,parse,nbits);
+	cvt_gray(flags,parse,(flags&TR_RJUSTIFY)?((nbits+3)&~3):nbits);
 
 	for(i=0;i<nbits;i+=4)
 		{
@@ -1317,7 +1328,7 @@ else if(flags&TR_OCT)
 	parse=(flags&TR_RJUSTIFY)
 		?(newbuff+((nbits%3)?(nbits%3):3))
 		:(newbuff+3);
-	cvt_gray(flags,parse,nbits);
+	cvt_gray(flags,parse,(flags&TR_RJUSTIFY)?(((nbits+2)/3)*3):nbits);
 
 	for(i=0;i<nbits;i+=3)
 		{
@@ -1410,10 +1421,12 @@ else if(flags&TR_REAL)
 	{
 	char *parse;
 
-	if(nbits==64)
+	if((nbits==64) || (nbits == 32))
 		{
 		UTimeType utt = LLDescriptor(0);
 		double d;
+		float f;
+		uint32_t utt_32;
 
 		parse=newbuff+3;
 		cvt_gray(flags,parse,nbits);
@@ -1435,9 +1448,19 @@ else if(flags&TR_REAL)
 				}
 			}
 
-		memcpy(&d, &utt, sizeof(double));
-		os=/*pnt=*/(char *)calloc_2(1,32); /* scan-build */
-		sprintf(os, "%.16g", d);
+		os=/*pnt=*/(char *)calloc_2(1,64); /* scan-build */
+
+		if(nbits==64)
+			{
+			memcpy(&d, &utt, sizeof(double));
+			sprintf(os, "%.16g", d);
+			}
+			else
+			{
+			utt_32 = utt;
+			memcpy(&f, &utt_32, sizeof(float));
+			sprintf(os, "%f", f);
+			}
 		}
 		else
 		{
@@ -1767,11 +1790,12 @@ if(flags&TR_REVERSE)
 
 if(flags&TR_REAL)
 	{
-	if(nbits==64) /* fail (NaN) otherwise */
+	if((nbits==64) || (nbits == 32)) /* fail (NaN) otherwise */
 		{
 		char *parse;
 		UTimeType val=0;
 		unsigned char fail=0;
+		uint32_t val_32;
 
 		parse=newbuff+3;
 		for(i=0;i<nbits;i++)
@@ -1783,7 +1807,17 @@ if(flags&TR_REAL)
 			}
 		if(!fail)
 			{
-			memcpy(&retval, &val, sizeof(double)); /* otherwise strict-aliasing rules problem if retval = *(double *)&val; */
+	                if(nbits==64)
+        	                {
+				memcpy(&retval, &val, sizeof(double)); /* otherwise strict-aliasing rules problem if retval = *(double *)&val; */
+        	                }
+        	                else
+        	                {
+				float f;
+        	                val_32 = val;
+				memcpy(&f, &val_32, sizeof(float)); /* otherwise strict-aliasing rules problem if retval = *(double *)&val; */
+				retval = (double)f;
+        	                }
 			}
 		}
 	}
