@@ -125,6 +125,7 @@ GLOBALS->zoom_pow10_snap = g_old->zoom_pow10_snap;
 GLOBALS->zoom_dyn = g_old->zoom_dyn;
 GLOBALS->zoom_dyne = g_old->zoom_dyne;
 GLOBALS->hier_ignore_escapes = g_old->hier_ignore_escapes;
+GLOBALS->sst_dbl_action_type = g_old->sst_dbl_action_type;
 
 reformat_time(timestr, GLOBALS->tims.first + GLOBALS->global_time_offset, GLOBALS->time_dimension);
 gtk_entry_set_text(GTK_ENTRY(GLOBALS->from_entry),timestr);
@@ -701,6 +702,7 @@ if(!GLOBALS)
 	GLOBALS->extload_max_tree = old_g->extload_max_tree;
 	GLOBALS->do_hier_compress = old_g->do_hier_compress;
 	GLOBALS->disable_auto_comphier = old_g->disable_auto_comphier;
+	GLOBALS->sst_dbl_action_type = old_g->sst_dbl_action_type;
 
 	strcpy2_into_new_context(GLOBALS, &GLOBALS->sst_exclude_filename, &old_g->sst_exclude_filename);
 
